/*******************************************************************************
* File Name: AL_ERR.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AL_ERR.h"


/*******************************************************************************
* Function Name: AL_ERR_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void AL_ERR_Write(uint8 value) 
{
    uint8 staticBits = (AL_ERR_DR & (uint8)(~AL_ERR_MASK));
    AL_ERR_DR = staticBits | ((uint8)(value << AL_ERR_SHIFT) & AL_ERR_MASK);
}


/*******************************************************************************
* Function Name: AL_ERR_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void AL_ERR_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(AL_ERR_0, mode);
}


/*******************************************************************************
* Function Name: AL_ERR_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro AL_ERR_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 AL_ERR_Read(void) 
{
    return (AL_ERR_PS & AL_ERR_MASK) >> AL_ERR_SHIFT;
}


/*******************************************************************************
* Function Name: AL_ERR_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 AL_ERR_ReadDataReg(void) 
{
    return (AL_ERR_DR & AL_ERR_MASK) >> AL_ERR_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(AL_ERR_INTSTAT) 

    /*******************************************************************************
    * Function Name: AL_ERR_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 AL_ERR_ClearInterrupt(void) 
    {
        return (AL_ERR_INTSTAT & AL_ERR_MASK) >> AL_ERR_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
