/*******************************************************************************
* File Name: DC_Motor_1_QuadDec_PM.c
* Version 3.0
*
* Description:
*  This file contains the setup, control and status commands to support 
*  component operations in low power mode.  
*
* Note:
*  None.
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DC_Motor_1_QuadDec.h"

static DC_Motor_1_QuadDec_BACKUP_STRUCT DC_Motor_1_QuadDec_backup = {0u};


/*******************************************************************************
* Function Name: DC_Motor_1_QuadDec_SaveConfig
********************************************************************************
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DC_Motor_1_QuadDec_SaveConfig(void) 
{
    #if (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT)
        DC_Motor_1_QuadDec_Cnt8_SaveConfig();
    #else 
        /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_16_BIT) || 
         * (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_32_BIT)
         */
        DC_Motor_1_QuadDec_Cnt16_SaveConfig();
    #endif /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: DC_Motor_1_QuadDec_RestoreConfig
********************************************************************************
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DC_Motor_1_QuadDec_RestoreConfig(void) 
{
    #if (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT)
        DC_Motor_1_QuadDec_Cnt8_RestoreConfig();
    #else 
        /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_16_BIT) || 
         * (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_32_BIT) 
         */
        DC_Motor_1_QuadDec_Cnt16_RestoreConfig();
    #endif /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT) */
}


/*******************************************************************************
* Function Name: DC_Motor_1_QuadDec_Sleep
********************************************************************************
* 
* Summary:
*  Prepare Quadrature Decoder Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  DC_Motor_1_QuadDec_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void DC_Motor_1_QuadDec_Sleep(void) 
{
    if (0u != (DC_Motor_1_QuadDec_SR_AUX_CONTROL & DC_Motor_1_QuadDec_INTERRUPTS_ENABLE))
    {
        DC_Motor_1_QuadDec_backup.enableState = 1u;
    }
    else /* The Quadrature Decoder Component is disabled */
    {
        DC_Motor_1_QuadDec_backup.enableState = 0u;
    }

    DC_Motor_1_QuadDec_Stop();
    DC_Motor_1_QuadDec_SaveConfig();
}


/*******************************************************************************
* Function Name: DC_Motor_1_QuadDec_Wakeup
********************************************************************************
*
* Summary:
*  Prepare Quadrature Decoder Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  DC_Motor_1_QuadDec_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void DC_Motor_1_QuadDec_Wakeup(void) 
{
    DC_Motor_1_QuadDec_RestoreConfig();

    if (DC_Motor_1_QuadDec_backup.enableState != 0u)
    {
        #if (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT)
            DC_Motor_1_QuadDec_Cnt8_Enable();
        #else 
            /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_16_BIT) || 
            *  (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_32_BIT) 
            */
            DC_Motor_1_QuadDec_Cnt16_Enable();
        #endif /* (DC_Motor_1_QuadDec_COUNTER_SIZE == DC_Motor_1_QuadDec_COUNTER_SIZE_8_BIT) */

        /* Enable component's operation */
        DC_Motor_1_QuadDec_Enable();
    } /* Do nothing if component's block was disabled before */
}


/* [] END OF FILE */

