/*******************************************************************************
* File Name: DC_Motor_2_PWM_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DC_Motor_2_PWM.h"

static DC_Motor_2_PWM_backupStruct DC_Motor_2_PWM_backup;


/*******************************************************************************
* Function Name: DC_Motor_2_PWM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DC_Motor_2_PWM_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void DC_Motor_2_PWM_SaveConfig(void) 
{

    #if(!DC_Motor_2_PWM_UsingFixedFunction)
        #if(!DC_Motor_2_PWM_PWMModeIsCenterAligned)
            DC_Motor_2_PWM_backup.PWMPeriod = DC_Motor_2_PWM_ReadPeriod();
        #endif /* (!DC_Motor_2_PWM_PWMModeIsCenterAligned) */
        DC_Motor_2_PWM_backup.PWMUdb = DC_Motor_2_PWM_ReadCounter();
        #if (DC_Motor_2_PWM_UseStatus)
            DC_Motor_2_PWM_backup.InterruptMaskValue = DC_Motor_2_PWM_STATUS_MASK;
        #endif /* (DC_Motor_2_PWM_UseStatus) */

        #if(DC_Motor_2_PWM_DeadBandMode == DC_Motor_2_PWM__B_PWM__DBM_256_CLOCKS || \
            DC_Motor_2_PWM_DeadBandMode == DC_Motor_2_PWM__B_PWM__DBM_2_4_CLOCKS)
            DC_Motor_2_PWM_backup.PWMdeadBandValue = DC_Motor_2_PWM_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(DC_Motor_2_PWM_KillModeMinTime)
             DC_Motor_2_PWM_backup.PWMKillCounterPeriod = DC_Motor_2_PWM_ReadKillTime();
        #endif /* (DC_Motor_2_PWM_KillModeMinTime) */

        #if(DC_Motor_2_PWM_UseControl)
            DC_Motor_2_PWM_backup.PWMControlRegister = DC_Motor_2_PWM_ReadControlRegister();
        #endif /* (DC_Motor_2_PWM_UseControl) */
    #endif  /* (!DC_Motor_2_PWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DC_Motor_2_PWM_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DC_Motor_2_PWM_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DC_Motor_2_PWM_RestoreConfig(void) 
{
        #if(!DC_Motor_2_PWM_UsingFixedFunction)
            #if(!DC_Motor_2_PWM_PWMModeIsCenterAligned)
                DC_Motor_2_PWM_WritePeriod(DC_Motor_2_PWM_backup.PWMPeriod);
            #endif /* (!DC_Motor_2_PWM_PWMModeIsCenterAligned) */

            DC_Motor_2_PWM_WriteCounter(DC_Motor_2_PWM_backup.PWMUdb);

            #if (DC_Motor_2_PWM_UseStatus)
                DC_Motor_2_PWM_STATUS_MASK = DC_Motor_2_PWM_backup.InterruptMaskValue;
            #endif /* (DC_Motor_2_PWM_UseStatus) */

            #if(DC_Motor_2_PWM_DeadBandMode == DC_Motor_2_PWM__B_PWM__DBM_256_CLOCKS || \
                DC_Motor_2_PWM_DeadBandMode == DC_Motor_2_PWM__B_PWM__DBM_2_4_CLOCKS)
                DC_Motor_2_PWM_WriteDeadTime(DC_Motor_2_PWM_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(DC_Motor_2_PWM_KillModeMinTime)
                DC_Motor_2_PWM_WriteKillTime(DC_Motor_2_PWM_backup.PWMKillCounterPeriod);
            #endif /* (DC_Motor_2_PWM_KillModeMinTime) */

            #if(DC_Motor_2_PWM_UseControl)
                DC_Motor_2_PWM_WriteControlRegister(DC_Motor_2_PWM_backup.PWMControlRegister);
            #endif /* (DC_Motor_2_PWM_UseControl) */
        #endif  /* (!DC_Motor_2_PWM_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DC_Motor_2_PWM_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DC_Motor_2_PWM_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DC_Motor_2_PWM_Sleep(void) 
{
    #if(DC_Motor_2_PWM_UseControl)
        if(DC_Motor_2_PWM_CTRL_ENABLE == (DC_Motor_2_PWM_CONTROL & DC_Motor_2_PWM_CTRL_ENABLE))
        {
            /*Component is enabled */
            DC_Motor_2_PWM_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DC_Motor_2_PWM_backup.PWMEnableState = 0u;
        }
    #endif /* (DC_Motor_2_PWM_UseControl) */

    /* Stop component */
    DC_Motor_2_PWM_Stop();

    /* Save registers configuration */
    DC_Motor_2_PWM_SaveConfig();
}


/*******************************************************************************
* Function Name: DC_Motor_2_PWM_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DC_Motor_2_PWM_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DC_Motor_2_PWM_Wakeup(void) 
{
     /* Restore registers values */
    DC_Motor_2_PWM_RestoreConfig();

    if(DC_Motor_2_PWM_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DC_Motor_2_PWM_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
