/*******************************************************************************
* File Name: EC_EEPROM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control and status commands for the EzI2C
*  component.  Actual protocol and operation code resides in the interrupt
*  service routine file.
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "EC_EEPROM.h"
#include "EC_EEPROM_EEPROM.h"

#include "CyLib.h"

/* Current state of I2C state machine */
extern volatile uint8 EC_EEPROM_curState;

/* Status byte */
extern volatile uint8 EC_EEPROM_curStatus;

/* Pointer to data exposed to I2C Master */
extern volatile uint8 * EC_EEPROM_dataPtrS1;

#if(CY_PSOC3)
    extern EC_EEPROM_BACKUP_STRUCT  EC_EEPROM_backup;
#endif  /* (CY_PSOC3) */

#if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)

    /* Offset for read and write operations, set at each write sequence */
    extern volatile uint8   EC_EEPROM_rwOffsetS1;

    /* Points to next value to be read or written */
    extern volatile uint8   EC_EEPROM_rwIndexS1;

    /* Offset where data is read only */
    extern volatile uint8   EC_EEPROM_wrProtectS1;

    /* Size of array between 1 and 255 */
    extern volatile uint8   EC_EEPROM_bufSizeS1;

#else   /* 16 bit sub-address */

    /* Offset for read and write operations, set at each write sequence */
    extern volatile uint16  EC_EEPROM_rwOffsetS1;

    /* Points to next value to be read or written */
    extern volatile uint16  EC_EEPROM_rwIndexS1;

    /* Offset where data is read only */
    extern volatile uint16  EC_EEPROM_wrProtectS1;

    /* Size of array between 1 and 65535 */
    extern volatile uint16  EC_EEPROM_bufSizeS1;

#endif  /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */


#if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

    /* Pointer to data exposed to I2C Master */
    extern volatile uint8 * EC_EEPROM_dataPtrS2;

    /* Software address compare 1 */
    extern volatile uint8   EC_EEPROM_addrS1;

    /* Software address compare 2 */
    extern volatile uint8   EC_EEPROM_addrS2;

    #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)

        /* Offset for read and write operations, set at each write sequence */
        extern volatile uint8   EC_EEPROM_rwOffsetS2;

        /* Points to next value to be read or written */
        extern volatile uint8   EC_EEPROM_rwIndexS2;

        /* Offset where data is read only */
        extern volatile uint8   EC_EEPROM_wrProtectS2;

        /* Size of array between 1 and 255 */
        extern volatile uint8   EC_EEPROM_bufSizeS2;

    #else /* 16 bit subaddress */

        /* Offset for read and write operations, set at each write sequence */
        extern volatile uint16  EC_EEPROM_rwOffsetS2;

        /* Points to next value to be read or written */
        extern volatile uint16  EC_EEPROM_rwIndexS2;

        /* Offset where data is read only */
        extern volatile uint16  EC_EEPROM_wrProtectS2;

        /* Size of array between 1 and 65535 */
        extern volatile uint16  EC_EEPROM_bufSizeS2;

    #endif /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */

#endif /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */

uint8 EC_EEPROM_initVar = 0u;

#if(EC_EEPROM_WAKEUP_ENABLED)
    CY_ISR_PROTO(EC_EEPROM_WAKEUP_ISR);
    volatile uint8 EC_EEPROM_wakeupSource;
#endif /* (EC_EEPROM_WAKEUP_ENABLED) */


/*******************************************************************************
* Function Name: EC_EEPROM_Start
********************************************************************************
*
* Summary:
*  Starts the component and enables the interupt. If this function is called at
*  first (or EC_EEPROM_initVar was cleared, then EC_EEPROM_Init()
*  function is called and all offsets and pointers are reset. Anyway, the
*  state machine state is set to IDLE, status variable is cleared and the
*  interrupt is enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_initVar - is used to indicate initial configuration
*  of this component.  The variable is initialized to zero and set to 1
*  the first time EC_EEPROM_Start() is called. This allows for component
*  initialization without re-initialization in all subsequent calls
*  to the EC_EEPROM_Start() routine.
*
*  EC_EEPROM_dataPtrS1 global variable, which stores pointer to the
*  data exposed to an I2C master for the first slave address is reset if
*  EC_EEPROM_initVar is set 0 by EC_EEPROM_initVar function call.
*
*  EC_EEPROM_rwOffsetS1 - global variable, which stores offset for read
*  and write operations, is set at each write sequence of the first slave
*  address is reset if EC_EEPROM_initVar is 0, by
*  EC_EEPROM_initVar function call.
*
*  EC_EEPROM_rwIndexS1 - global variable, which stores pointer to the
*  next value to be read or written for the first slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
* EC_EEPROM_wrProtectS1 - global variable, which stores offset where data
*  is read only for the first slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
* EC_EEPROM_bufSizeS1 - global variable, which stores size of data array
*  exposed to an I2C master for the first slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
*  EC_EEPROM_dataPtrS2 - global variable, which stores pointer to the
*  data exposed to an I2C master for the second slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
*  EC_EEPROM_rwOffsetS2 - global variable, which stores offset for read
*  and write operations, is set at each write sequence of the second slave
*  device is reset if EC_EEPROM_initVar is 0, by EC_EEPROM_initVar
*  function call.
*
*  EC_EEPROM_rwIndexS2 - global variable, which stores pointer to the
*  next value to be read or written for the second slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
* EC_EEPROM_wrProtectS2 - global variable, which stores offset where data
*  is read only for the second slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
* EC_EEPROM_bufSizeS2 - global variable, which stores size of data array
*  exposed to an I2C master for the second slave address is reset if
*  EC_EEPROM_initVar is 0, by EC_EEPROM_initVar function call.
*
* Side Effects:
*  This component automatically enables it's interrupt. If I2C is enabled
*  without the interrupt enabled, it could lock up the I2C bus.
*
* Reentrant:
*  No
*
*******************************************************************************/
void EC_EEPROM_Start(void) 
{
    int i;
    
    if(0u == EC_EEPROM_initVar)
    {
        /* Initialize component's parameters */
        EC_EEPROM_Init();

        /* Set init flag */
        EC_EEPROM_initVar = 1u;
    }

    /* Enable slave mode for the device */
    EC_EEPROM_Enable();
    
    EC_EEPROM_EEPROM_Start();
    
    for (i=0; i<CYDEV_EE_SIZE; i++)                                                     // Fill the RAM buffer from the EEPROM
        EC_EEPROM_EEPROM_Contents[i] = CY_GET_REG8(CYDEV_EE_BASE + i);    

    EC_EEPROM_SetBuffer1(CYDEV_EE_SIZE, CYDEV_EE_SIZE, EC_EEPROM_EEPROM_Contents);
}


/*******************************************************************************
* Function Name: EC_EEPROM_Stop
********************************************************************************
*
* Summary:
*  Disable the I2C block's slave operation and the corresponding interrupt.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EC_EEPROM_Stop(void) 
{
    uint8 interruptState;

    /* Disable Interrupt */
    EC_EEPROM_DisableInt();

    #if(CY_PSOC3)

        /* Store resgisters which are held in reset when Slave is disabled */
        EC_EEPROM_backup.adr = EC_EEPROM_ADDR_REG;
        EC_EEPROM_backup.clkDiv1  = EC_EEPROM_CLKDIV1_REG;
        EC_EEPROM_backup.clkDiv2  = EC_EEPROM_CLKDIV2_REG;

        /* Reset fixed-function block */
        EC_EEPROM_CFG_REG &= ~EC_EEPROM_CFG_EN_SLAVE;
        EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_EN_SLAVE;

        /* Restore registers */
        EC_EEPROM_ADDR_REG = EC_EEPROM_backup.adr;
        EC_EEPROM_CLKDIV1_REG = EC_EEPROM_backup.clkDiv1;
        EC_EEPROM_CLKDIV2_REG = EC_EEPROM_backup.clkDiv2;

    #endif  /* (CY_PSOC3) */

    /* Enter critical section */
    interruptState = CyEnterCriticalSection();

    /* Disable I2C block in Active mode template */
    EC_EEPROM_PM_ACT_CFG_REG &= ~EC_EEPROM_ACT_PWR_EN;

    /* Disable I2C block in Alternate Active (Standby) mode template */
    EC_EEPROM_PM_STBY_CFG_REG &= ~EC_EEPROM_STBY_PWR_EN;

    /* Exit critical section */
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: EC_EEPROM_EnableInt
********************************************************************************
*
* Summary:
*  Enables the interrupt service routine for the component.  This is normally
*  handled with the start command.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EC_EEPROM_EnableInt(void) 
{
    /* Enable interrupt */
    CyIntEnable(EC_EEPROM_ISR_NUMBER);
}


/*******************************************************************************
* Function Name: EC_EEPROM_DisableInt
********************************************************************************
*
* Summary:
*  Disable I2C interrupts. Normally this function is not required since the
*  Stop function disables the interrupt. If the I2C interrupt is disabled while
*  the I2C master is still running, it may cause the I2C bus to lock up.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  If the I2C interrupt is disabled and the master is addressing the current
*  slave, the bus will be locked until the interrupt is re-enabled.
*
*******************************************************************************/
void EC_EEPROM_DisableInt(void) 
{
    /* Disable interrupt */
    CyIntDisable(EC_EEPROM_ISR_NUMBER);
}


/*******************************************************************************
* Function Name: EC_EEPROM_SetAddress1
********************************************************************************
*
* Summary:
*  This function sets the main address of this I2C slave device. This value may
*  be any value between 0 and 127.
*
* Parameters:
*  address:  The 7-bit slave address between 0 and 127.
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_addrS1 - the new slave address for the first slave device is
*  saved in it, if the component is configured to act as two slave devices.
*
* Reentrant:
*  No, if two addresses are used.
*
*******************************************************************************/
void EC_EEPROM_SetAddress1(uint8 address) 
{
    #if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

        /* Address is stored in variable */
        EC_EEPROM_addrS1  = address & EC_EEPROM_SADDR_MASK;

    #else

        /* Address is stored in hardware */
        EC_EEPROM_ADDR_REG = address & EC_EEPROM_SADDR_MASK;

    #endif /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */
}


/*******************************************************************************
* Function Name: EC_EEPROM_GetAddress1
********************************************************************************
*
* Summary:
*  Returns address of the first slave device.
*
* Parameters:
*  None
*
* Return:
*  If the component is configured to has two slave addresses than primary
*  address is returned, otherwise address from the the address register is
*  returned.
*
* Global variables:
*  EC_EEPROM_addrS1 - if component is configured to has two slave
*  addresses than primary address is saved here, otherwise address is written to
*  the register.
*
* Reentrant:
*  No
*
*******************************************************************************/
uint8 EC_EEPROM_GetAddress1(void) 
{
    /* Get 1st slave address */
    #if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

        /* Return address from variable */
        return(EC_EEPROM_addrS1);

    #else

        /* Return address from hardware */
        return(EC_EEPROM_ADDR_REG);

    #endif /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */
}


/*******************************************************************************
* Function Name: EC_EEPROM_GetActivity
********************************************************************************
*
* Summary:
*  This function returns a nonzero value if the I2C read or write cycle
*  occurred since the last time this function was called.  The activity
*  flag resets to zero at the end of this function call.
*  The Read and Write busy flags are cleared when read, but the "BUSY"
*  flag is only cleared by an I2C Stop.
*
* Parameters:
*  None
*
* Return:
*  A non-zero value is returned if activity is detected:
*   EC_EEPROM_STATUS_READ1   Set if Read sequence is detected for first
*                                   address. Cleared when status read.
*
*   EC_EEPROM_STATUS_WRITE1  Set if Write sequence is detected for first
*                                   address. Cleared when status read.
*
*   EC_EEPROM_STATUS_READ2   Set if Read sequence is detected for second
*                                   address (if enabled). Cleared when status
*                                   read.
*
*   EC_EEPROM_STATUS_WRITE2  Set if Write sequence is detected for second
*                                   address (if enabled). Cleared when status
*                                   read.
*
*   EC_EEPROM_STATUS_BUSY    Set if Start detected, cleared when stop
*                                   detected.
*
*   EC_EEPROM_STATUS_ERR     Set when I2C hardware detected, cleared
*                                   when status read.
*
* Global variables:
*  EC_EEPROM_curStatus - global variable, which stores the current
*  component status.
*
* Reentrant:
*  No
*
*******************************************************************************/
uint8 EC_EEPROM_GetActivity(void) 
{
    uint8 tmpStatus;

    tmpStatus = EC_EEPROM_curStatus;

    /* Clear status, but no Busy one */
    EC_EEPROM_curStatus &= EC_EEPROM_STATUS_BUSY;

    return(tmpStatus);
}


/*******************************************************************************
* Function Name: EC_EEPROM_SetBuffer1
********************************************************************************
*
* Summary:
*  This function sets the buffer, size of the buffer, and the R/W boundry
*  for the memory buffer.
*
* Parameters:
*  size:  Size of the buffer in bytes.
*
*  rwBoundry: Sets how many bytes are writable in the beginning of the buffer.
*  This value must be less than or equal to the buffer size.
*
*  dataPtr:  Pointer to the data buffer.
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_dataPtrS1 - stores pointer to the data exposed to an I2C
*  master for the first slave address is modified with the the new pointer to
*  data, passed by function parameter.
*
*  EC_EEPROM_rwOffsetS1 - stores offset for read and write operations, is
*  modified at each write sequence of the first slave address is reset.
*
*  EC_EEPROM_rwIndexS1 - stores pointer to the next value to be read or
*  written for the first slave address is set to 0.
*
* Reentrant:
*  No
*
* Side Effects:
*  It is recommended to disable component interrupt before calling this function
*  and enable it afterwards for the proper component operation.
*
*******************************************************************************/
void EC_EEPROM_SetBuffer1(uint16 bufSize, uint16 rwBoundry, void * dataPtr) 
{
    /* Set pointer to data and clear index and offset. */
    EC_EEPROM_dataPtrS1   = dataPtr;
    EC_EEPROM_rwOffsetS1  = 0u;
    EC_EEPROM_rwIndexS1   = 0u;

    #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)
        EC_EEPROM_bufSizeS1   = (uint8) bufSize;
        EC_EEPROM_wrProtectS1 = (uint8) rwBoundry;
    #else
        EC_EEPROM_bufSizeS1   = bufSize;
        EC_EEPROM_wrProtectS1 = rwBoundry;
    #endif /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */
}


#if (EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS)
    /*******************************************************************************
    * Function Name: EC_EEPROM_SlaveSetSleepMode
    ********************************************************************************
    *
    * Summary:
    *  Disables the run time I2C regulator and enables the sleep Slave I2C.
    *  Should be called just prior to entering sleep. This function is only
    *  provided if a single I2C address is used.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  The I2C interrupt will be disabled if Wake up from Sleep mode option is
    *  enabled (only for PSoC3).
    *
    *******************************************************************************/
    void EC_EEPROM_SlaveSetSleepMode(void) 
    {
        #if(EC_EEPROM_WAKEUP_ENABLED)
            uint8 interruptState;

            /* Enable the I2C backup regulator  */
            interruptState = CyEnterCriticalSection();
            EC_EEPROM_PWRSYS_CR1_REG |= EC_EEPROM_PWRSYS_CR1_I2C_BACKUP;
            CyExitCriticalSection(interruptState);

            /* Set force nack before putting the device to power off mode.
            *  It is cleared on wake up.
            */
            EC_EEPROM_XCFG_REG |= EC_EEPROM_XCFG_FORCE_NACK;
            while(0u == (EC_EEPROM_XCFG_REG & EC_EEPROM_XCFG_SLEEP_READY))
            {
                /* Waits for ongoing transaction to be completed. */
            }
            
             /* Setup wakeup interrupt */
            EC_EEPROM_DisableInt();
            (void) CyIntSetVector(EC_EEPROM_ISR_NUMBER, &EC_EEPROM_WAKEUP_ISR);
            EC_EEPROM_wakeupSource = 0u; /* Clear wakeup event */
            EC_EEPROM_EnableInt();

            /* Leave interrupt enabled to wake up */
            
        #endif /* (EC_EEPROM_WAKEUP_ENABLED) */
    }


    /*******************************************************************************
    * Function Name: EC_EEPROM_SlaveSetWakeMode
    ********************************************************************************
    *
    * Summary:
    *  Disables the sleep EzI2C slave and re-enables the run time I2C.  Should be
    *  called just after awaking from sleep.  Must preserve address to continue.
    *  This function is only provided if a single I2C address is used.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  The I2C interrupt will be enabled if Wake up from Sleep mode option is
    *  enabled (only for PSoC3).
    *
    *******************************************************************************/
    void EC_EEPROM_SlaveSetWakeMode(void) 
    {
        #if(EC_EEPROM_WAKEUP_ENABLED)
            uint8 interruptState;

            interruptState = CyEnterCriticalSection();
            /* Disable the I2C regulator backup */
            EC_EEPROM_PWRSYS_CR1_REG &= ~EC_EEPROM_PWRSYS_CR1_I2C_BACKUP;
            CyExitCriticalSection(interruptState);

            /* Trigger I2C interrupt if wakeup interrupt was triggered before */
            EC_EEPROM_DisableInt();
            (void) CyIntSetVector(EC_EEPROM_ISR_NUMBER, &EC_EEPROM_ISR);
            if(0u != EC_EEPROM_wakeupSource)
            {
                CyIntSetPending(EC_EEPROM_ISR_NUMBER); /* Generate interrupt to release I2C bus */
            }
            EC_EEPROM_EnableInt();

        #endif /* (EC_EEPROM_WAKEUP_ENABLED) */
    }

#endif /* (EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS) */


#if (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)
    /*******************************************************************************
    * Function Name: EC_EEPROM_SetBuffer2
    ********************************************************************************
    *
    * Summary:
    *  This function sets the buffer pointer, size and read/write area for the
    *  second slave data. This is the data that is exposed to the I2C Master
    *  for the second I2C address. This function is only provided if two I2C
    *  addresses have been selected in the user parameters.
    *
    * Parameters:
    *  bufSize:  Size of the buffer exposed to the I2C master.
    *
    *  rwBoundry: Sets how many bytes are readable and writable by the the I2C
    *  master. This value must be less than or equal to the buffer size. Data
    *  located at offset rwBoundry and above are read only.
    *
    *  dataPtr:  This is a pointer to the data array or structure that is used
    *  for the I2C data buffer.
    *
    * Return:
    *  None
    *
    * Global variables:
    *  EC_EEPROM_dataPtrS2 - stores pointer to the data exposed to an I2C
    *  master for the second slave address is modified with the the new pointer to
    *  data, passed by function parameter.
    *
    *  EC_EEPROM_rwOffsetS2 - stores offset for read and write operations,
    *  is modified at each write sequence of the second slave address is reset.
    *
    *  EC_EEPROM_rwIndexS2 - stores pointer to the next value to be read or
    *  written for the second slave address is set to 0.
    *
    * Reentrant:
    *  No
    *
    * Side Effects:
    *  It is recommended to disable component interrupt before calling this
    *  function and enable it afterwards for the proper component operation.
    *
    *******************************************************************************/
    void EC_EEPROM_SetBuffer2(uint16 bufSize, uint16 rwBoundry, void * dataPtr) 
    {
        /* Set pointer to data and clear index and offset. */
        EC_EEPROM_dataPtrS2   = dataPtr;
        EC_EEPROM_rwOffsetS2  = 0u;
        EC_EEPROM_rwIndexS2   = 0u;

        #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)
            EC_EEPROM_bufSizeS2   = (uint8) bufSize;
            EC_EEPROM_wrProtectS2 = (uint8) rwBoundry;
        #else
            EC_EEPROM_bufSizeS2   = bufSize;
            EC_EEPROM_wrProtectS2 = rwBoundry;
        #endif /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */
    }


    /*******************************************************************************
    * Function Name: EC_EEPROM_SetAddress2
    ********************************************************************************
    *
    * Summary:
    *  Sets the I2C slave address for the second device. This value may be any
    *  value between 0 and 127. This function is only provided if two I2C
    *  addresses have been selected in the user parameters.
    *
    * Parameters:
    *  address:  The 7-bit slave address between 0 and 127.
    *
    * Return:
    *  None
    *
    * Global variables:
    *  EC_EEPROM_addrS2 - the secondary slave address is modified.
    *
    * Reentrant:
    *  No
    *
    *******************************************************************************/
    void EC_EEPROM_SetAddress2(uint8 address) 
    {
        /* Set slave address */
        EC_EEPROM_addrS2  = address & EC_EEPROM_SADDR_MASK;
    }


    /*******************************************************************************
    * Function Name: EC_EEPROM_GetAddress2
    ********************************************************************************
    *
    * Summary:
    *  Returns the I2C slave address for the second device. This function is only
    *  provided if two I2C addresses have been selected in the user parameters.
    *
    * Parameters:
    *  EC_EEPROM_addrS2 - global variable, which stores the second I2C
    *   address.
    *
    * Return:
    *  The secondary I2C slave address.
    *
    * Global variables:
    *  EC_EEPROM_addrS2 - the secondary slave address is used.
    *
    * Reentrant:
    *  No
    *
    *******************************************************************************/
    uint8 EC_EEPROM_GetAddress2(void) 
    {
        return(EC_EEPROM_addrS2);
    }

#endif  /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */


/*******************************************************************************
* Function Name: EC_EEPROM_Init
********************************************************************************
*
* Summary:
*  Initializes/restores default EZI2C configuration provided with customizer.
*  Usually called in EC_EEPROM_Start().
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_addrS1 - the new slave address for the first slave device is
*   saved.
*
*  EC_EEPROM_addrS2 - the new slave address for the second slave device
*   is saved, if EzI2C component is configured for two slave addresses.
*
* Reentrant:
*  No
*
* Side Effects:
*  All changes applied by API to the component's configuration will be reset.
*
*******************************************************************************/
void EC_EEPROM_Init(void) 
{
    #if(CY_PSOC5A)

        uint8 clkSel;

    #endif  /* (CY_PSOC5A) */

    /* Clear Status register */
    EC_EEPROM_CSR_REG  = 0x00u;

    #if(CY_PSOC5A)

        /* Enable I2C block's slave operation */
        EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_EN_SLAVE;

        /* The resolution of generated I2C bus SCL frequencies is reduced. */

        /* Temprorary set CLK divider to 16 */
        EC_EEPROM_CLKDIV_REG  = EC_EEPROM_CLK_DIV_16;

        /* Set clock divider for the I2C bus clock to be the closest HIGHER
        *  clock to ensure it can work with an ideal master clock.
        */
        for(clkSel = 0u; clkSel <= 6u; clkSel++ )
        {
            if((1u << clkSel) >= EC_EEPROM_DEFAULT_CLKDIV)
            {
                EC_EEPROM_CLKDIV_REG  = clkSel;
                break;
            }
        }

        /* Set clock rate to Fast mode 400k. This will give the Clock
        *  divider sufficient range to work bewteen 50 and 400 kbps.
        */
        EC_EEPROM_CFG_REG  |= EC_EEPROM_CFG_CLK_RATE_400;

    #elif(CY_PSOC3 || CY_PSOC5LP)

        /* Enable I2C block's slave operation.
        *  These revisions require slave to be enabled for registers to be
        *  written.
        */
        EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_EN_SLAVE;

        /* 8 LSB bits of the 10-bit are written with the divide factor */
		EC_EEPROM_CLKDIV1_REG = LO8(EC_EEPROM_DIVIDE_FACTOR);

        /* 2 MSB bits of the 10-bit are written with the divide factor */
		EC_EEPROM_CLKDIV2_REG = HI8(EC_EEPROM_DIVIDE_FACTOR);

        /* Define clock rate */
        if(EC_EEPROM_BUS_SPEED <= EC_EEPROM_BUS_SPEED_50KHZ)
        {   /* 50 kHz - 32 samples/bit */
            EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_CLK_RATE;
        }
        else
        {   /* 100kHz or 400kHz - 16 samples/bit */
            EC_EEPROM_CFG_REG &= ~EC_EEPROM_CFG_CLK_RATE;
        }

        /* if I2C block will be used as wake up source, this availabe only for
        * PSoC3 and PSoC5A.
        */
        #if(1u == EC_EEPROM_ENABLE_WAKEUP)

            /* Configure I2C address match to act as wake-up source */
           EC_EEPROM_XCFG_REG |= EC_EEPROM_XCFG_I2C_ON;

            /* Process sio_select and pselect */
            #if(EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS)
                if(EC_EEPROM__ANY != EC_EEPROM_BUS_PORT)
                {
                    /* SCL and SDA lines get their inputs from SIO block */
                    EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_PSELECT;

                    if(EC_EEPROM__I2C0 == EC_EEPROM_BUS_PORT)
                    {
                        /* SCL and SDA lines get their inputs from SIO1 */
                        EC_EEPROM_CFG_REG &= ~EC_EEPROM_CFG_SIO_SELECT;
                    }
                    else /* SIO2 */
                    {
                        /* SCL and SDA lines get their inputs from SIO2 */
                        EC_EEPROM_CFG_REG |= EC_EEPROM_CFG_SIO_SELECT;
                    }
                }
                else    /* GPIO is used */
                {
                    /* SCL and SDA lines get their inputs from GPIO module. */
                    EC_EEPROM_CFG_REG &= ~EC_EEPROM_CFG_PSELECT;
                }
            #endif  /* (EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS) */

        #endif /* (1u == EC_EEPROM_ENABLE_WAKEUP) */

    #endif  /* (CY_PSOC5A) */


    #if(EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS)

        /* Set default slave address */
        EC_EEPROM_ADDR_REG  = EC_EEPROM_DEFAULT_ADDR1;

        /* Turn on hardware address detection */
        EC_EEPROM_XCFG_REG  |= EC_EEPROM_XCFG_HDWR_ADDR_EN;

    #else   /* Two devices */

        /* Set default slave addresses */
        EC_EEPROM_addrS1  = EC_EEPROM_DEFAULT_ADDR1;
        EC_EEPROM_addrS2  = EC_EEPROM_DEFAULT_ADDR2;

    #endif  /* End of (EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS) */

    /* Reset offsets and pointers */
    EC_EEPROM_dataPtrS1 = (uint8 *)0x0000u;
    EC_EEPROM_rwOffsetS1 = 0u;
    EC_EEPROM_rwIndexS1 = 0u;
    EC_EEPROM_wrProtectS1 = 0u;
    EC_EEPROM_bufSizeS1 = 0u;

    /* Reset offsets and pointers for 2nd slave address */
    #if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)
        EC_EEPROM_dataPtrS2 = (uint8 *)0x0000u;
        EC_EEPROM_rwOffsetS2 = 0u;
        EC_EEPROM_rwIndexS2 = 0u;
        EC_EEPROM_wrProtectS2 = 0u;
        EC_EEPROM_bufSizeS2 = 0u;
    #endif  /* End of (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */

    /* Enable the I2C block clock */
    EC_EEPROM_XCFG_REG  |= EC_EEPROM_XCFG_CLK_EN;
}


/*******************************************************************************
* Function Name: EC_EEPROM_Enable
********************************************************************************
*
* Summary:
*  Enables the I2C block operation, sets interrupt priority, sets
*  interrupt vector, clears pending interrupts and enables interrupts. Clears
*  status variables and reset state machine variable.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_curStatus - this global variable are cleared, it stores the
*  current component status.
*
* EC_EEPROM_curState - global variable are cleared, it stores the current
*  state of the state machine.
*
* Reentrant:
*  No
*
*******************************************************************************/
void EC_EEPROM_Enable(void) 
{
    uint8 interruptState;

    /* Enter critical section */
    interruptState = CyEnterCriticalSection();

    /* Enable I2C block in Active mode template */
    EC_EEPROM_PM_ACT_CFG_REG |= EC_EEPROM_ACT_PWR_EN;

    /* Enable I2C block in Alternate Active (Standby) mode template */
    EC_EEPROM_PM_STBY_CFG_REG |= EC_EEPROM_STBY_PWR_EN;

    /* Exit critical section */
    CyExitCriticalSection(interruptState);

    /* Set the interrupt priority */
    CyIntSetPriority(EC_EEPROM_ISR_NUMBER, EC_EEPROM_ISR_PRIORITY);

    /* Set the interrupt vector */
    CyIntSetVector(EC_EEPROM_ISR_NUMBER, EC_EEPROM_ISR);

    /* Clear any pending interrupt */
    CyIntClearPending(EC_EEPROM_ISR_NUMBER);

    /* Reset State Machine to IDLE */
    EC_EEPROM_curState = EC_EEPROM_SM_IDLE;

    /* Clear Status variable */
    EC_EEPROM_curStatus = 0x00u;

    /* Enable the interrupt */
    EC_EEPROM_EnableInt();
}


/*******************************************************************************
*
* Added by Shadow
*
* Function Name: EC_EEPROM_HandleWriting
********************************************************************************
*
* Summary:
*  If there are any pending EEPROM writes, this function starts them.
*  It needs to be called in the user's main loop. Typically every 1ms,
*  or perhaps every 10ms.
* 
* Parameters:
*  None
*
* Return:
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
unsigned char * rowAddress;
void EC_EEPROM_HandleWriting(void)
{
    if (EC_EEPROM_EEPROM_row_queue_head !=  EC_EEPROM_EEPROM_row_queue_tail)
    {
        if (EC_EEPROM_EEPROM_QueryWrite() != CYRET_STARTED)
        {
            unsigned char rowNumber  = EC_EEPROM_EEPROM_row_queue[EC_EEPROM_EEPROM_row_queue_tail++];
            unsigned int  byteNumber = rowNumber;
            
            byteNumber <<= 4;
            rowAddress = EC_EEPROM_dataPtrS1 + byteNumber;
            
            CySetTemp();                
            EC_EEPROM_EEPROM_StartWrite(rowAddress, rowNumber);
        }
    }
}


/*******************************************************************************
*
* Added by Shadow
*
* Function Name: EC_EEPROM_WriteRAMInt16
********************************************************************************
*
* Summary:
*  Write a 16-bit integer into the EEPROM buffer. Handles byte swapping.
*  
*  
* 
* Parameters:
*  i       - 16-bit integer to write
*  address - 16-bit word address to read from
*
* Return:
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
void EC_EEPROM_WriteRAMInt16u(unsigned int i, unsigned int address)
{
    #if (CY_PSOC3)
        if (address < (CYDEV_EE_SIZE/2))
        {
            EC_EEPROM_EEPROM_Contents[0+ (address<<1)] = *(((unsigned char*)&i) +1);
            EC_EEPROM_EEPROM_Contents[1+ (address<<1)] = *(((unsigned char*)&i) +0);
        }
    #else
        if (address < (CYDEV_EE_SIZE/2))
        {
            EC_EEPROM_EEPROM_Contents[0+ (address<<1)] = *(((unsigned char*)&i) +0);
            EC_EEPROM_EEPROM_Contents[1+ (address<<1)] = *(((unsigned char*)&i) +1);
        }
    #endif
    
}



/*******************************************************************************
*
* Added by Shadow
*
* Function Name: EC_EEPROM_ReadRAMInt16
********************************************************************************
*
* Summary:
*  Read a 16-bit integer from the EEPROM buffer. Handles byte swapping.
*  
*  
* 
* Parameters:
*  address - 16-bit word address to read from
*
* Return:
*  16-bit integer read from the EEPROM's RAM buffer
*
* Reentrant:
*  No
*
*******************************************************************************/
unsigned int EC_EEPROM_ReadRAMInt16u(unsigned int address)
{
    unsigned int i;
    
    if (address < (CYDEV_EE_SIZE/2))
    {
        *(((unsigned char*)&i) +1) = EC_EEPROM_EEPROM_Contents[0+ (address<<1)];
        *(((unsigned char*)&i) +0) = EC_EEPROM_EEPROM_Contents[1+ (address<<1)];
    }
    
    return i;
}



#if(EC_EEPROM_WAKEUP_ENABLED)
    /*******************************************************************************
    * Function Name: EC_EEPROM_WAKEUP_ISR
    ********************************************************************************
    *
    * Summary:
    *  Empty interrupt handler to trigger after wakeup.
    *
    * Parameters:
    *  void
    *
    * Return:
    *  void
    *
    *******************************************************************************/
    CY_ISR(EC_EEPROM_WAKEUP_ISR)
    {
        EC_EEPROM_wakeupSource = 1u;  /* I2C was wakeup source */
        
        /* The SCL is stretched until EZI2C_SlaveSetWakeMode() is called */
    }
#endif /* (EC_EEPROM_WAKEUP_ENABLED) */

/* [] END OF FILE */


