/*******************************************************************************
* File Name: EC_EEPROM.h
* Version 1.80
*
* Description:
*  This is the header file for the EzI2C user module.  It contains function
*  prototypes and constants for the users convenience.
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_EZI2C_EC_EEPROM_H)
#define CY_EZI2C_EC_EEPROM_H

#include "cytypes.h"
#include "cyfitter.h"

/***************************************
*   Added by Shadow
*   Used by EEPROM writing process
***************************************/

#define EC_EEPROM_EEPROM_ROW_QUEUE_LENGTH  (CYDEV_EE_SIZE / CYDEV_EEPROM_ROW_SIZE)
extern uint8   EC_EEPROM_EEPROM_row_queue[EC_EEPROM_EEPROM_ROW_QUEUE_LENGTH];
extern uint8   EC_EEPROM_EEPROM_row_queue_head;
extern uint8   EC_EEPROM_EEPROM_row_queue_tail;
extern uint8   EC_EEPROM_EEPROM_Contents[CYDEV_EE_SIZE];

void EC_EEPROM_HandleWriting(void);
void EC_EEPROM_WriteRAMInt16u(unsigned int i, unsigned int address);

/***************************************
*   Conditional Compilation Parameters
***************************************/

#define EC_EEPROM_ADDRESSES         (1u)
#define EC_EEPROM_ONE_ADDRESS       (0x01u)
#define EC_EEPROM_TWO_ADDRESSES     (0x02u)

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5A)
    #error Component EZI2C_v1_80 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5A) */


/***************************************
*   Data Struct Definition
***************************************/

/* Low power modes API Support */
typedef struct _EC_EEPROM_backupStruct
{
    uint8   enableState;

    uint8   xcfg;
    uint8   adr;
    uint8   cfg;
    
    #if(CY_PSOC5A)
        
        uint8   clkDiv;
        
    #else
        
        uint8   clkDiv1;
        uint8   clkDiv2;
        
    #endif /* (CY_PSOC5A) */
}   EC_EEPROM_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void    EC_EEPROM_Start(void) ;
void    EC_EEPROM_Stop(void) ;
void    EC_EEPROM_EnableInt(void) ;
void    EC_EEPROM_DisableInt(void) ;

void    EC_EEPROM_SetAddress1(uint8 address) ;
uint8   EC_EEPROM_GetAddress1(void) ;
void    EC_EEPROM_SetBuffer1(uint16 bufSize, uint16 rwBoundry, void * dataPtr) ;
uint8   EC_EEPROM_GetActivity(void) ;
void    EC_EEPROM_Init(void) ;
void    EC_EEPROM_Enable(void) ;
void    EC_EEPROM_Sleep(void) ;
void    EC_EEPROM_Wakeup(void) ;
void    EC_EEPROM_SaveConfig(void) ;
void    EC_EEPROM_RestoreConfig(void) ;

CY_ISR_PROTO(EC_EEPROM_ISR);

#if(EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS)

    void    EC_EEPROM_SlaveSetSleepMode(void) ;
    void    EC_EEPROM_SlaveSetWakeMode(void) ;

#endif /* (EC_EEPROM_ADDRESSES == EC_EEPROM_ONE_ADDRESS)*/

#if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

    void    EC_EEPROM_SetAddress2(uint8 address );
    uint8   EC_EEPROM_GetAddress2(void) ;
    void    EC_EEPROM_SetBuffer2(uint16 bufSize, uint16 rwBoundry, void * dataPtr) ;

#endif  /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */


/***************************************
*   Initial Parameter Constants
***************************************/

#define EC_EEPROM_DEFAULT_ADDR1      (80u)
#define EC_EEPROM_DEFAULT_ADDR2      (9u)
#define EC_EEPROM_ENABLE_WAKEUP      (0u)
#define EC_EEPROM_BUS_SPEED          (1000u)
#define EC_EEPROM_SUBADDR_WIDTH      (1u)
#define EC_EEPROM_BUS_PORT           (0u)

#define EC_EEPROM_WAKEUP_ENABLED     (0u != EC_EEPROM_ENABLE_WAKEUP)


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated type*/
#define EC_EEPROM__ANY 0
#define EC_EEPROM__I2C0 1
#define EC_EEPROM__I2C1 2



/***************************************
*              API Constants
***************************************/

/* Status bit definition */

/* A read addr 1 operation occured since last status check */
#define EC_EEPROM_STATUS_READ1       (0x01u)

/* A Write addr 1 opereation occured since last status check */
#define EC_EEPROM_STATUS_WRITE1      (0x02u)

/* A read addr 2 operation occured since last status check */
#define EC_EEPROM_STATUS_READ2       (0x04u)

/* A Write addr 2 opereation occured since last status check */
#define EC_EEPROM_STATUS_WRITE2      (0x08u)

/* A start has occured, but a Stop has not been detected */
#define EC_EEPROM_STATUS_BUSY        (0x10u)

/* Addr 1 read busy */
#define EC_EEPROM_STATUS_RD1BUSY     (0x11u)

/* Addr 1 write busy */
#define EC_EEPROM_STATUS_WR1BUSY     (0x12u)

/* Addr 2 read busy */
#define EC_EEPROM_STATUS_RD2BUSY     (0x14u)

/* Addr 2 write busy */
#define EC_EEPROM_STATUS_WR2BUSY     (0x18u)

/* Mask for status bits. */
#define EC_EEPROM_STATUS_MASK        (0x1Fu)

/* An Error occured since last read */
#define EC_EEPROM_STATUS_ERR         (0x80u)

/* Dummy data to be sent to master */
#define EC_EEPROM_DUMMY_DATA         (0xFFu)

/* The I2C Master bits in I2C cinfiguration register */
#define EC_EEPROM_I2C_MASTER_MASK    (0xDDu)

/* Component's enable/disable state */
#define EC_EEPROM_ENABLED            (0x01u)
#define EC_EEPROM_DISABLED           (0x00u)


#if(CY_PSOC5A)

    /* Samples per bit. Other value is not used */
    #define EC_EEPROM_16_SAMPLES_PER_BIT    (16u)

    /* Default CLK Divider =
    *  BusClock / (I2C_Bus_Speed * EC_EEPROM_16_SAMPLES_PER_BIT)
    */
    #define EC_EEPROM_DEFAULT_CLKDIV (BCLK__BUS_CLK__KHZ / \
       (EC_EEPROM_BUS_SPEED * EC_EEPROM_16_SAMPLES_PER_BIT))
    
#else

    #define EC_EEPROM_BUS_SPEED_50KHZ      (50u)
	
	/* Bus speed grater 50kHz requires 16 oversample rate */
	#if (EC_EEPROM_BUS_SPEED <= EC_EEPROM_BUS_SPEED_50KHZ)

		#define EC_EEPROM_OVER_SAMPLE_RATE       (32u)

	#else

		#define EC_EEPROM_OVER_SAMPLE_RATE       (16u)

	#endif  /* End (EC_EEPROM_BUS_SPEED <= EC_EEPROM_BUS_SPEED_50KHZ) */
    
	/* Divide factor calculation */
	#define EC_EEPROM_DIVIDE_FACTOR_WITH_FRACT_BYTE  \
                    (((uint32) BCLK__BUS_CLK__KHZ << 8u) / ((uint32)EC_EEPROM_BUS_SPEED * \
                    EC_EEPROM_OVER_SAMPLE_RATE))
                    
	#define EC_EEPROM_DIVIDE_FACTOR  (((uint32) EC_EEPROM_DIVIDE_FACTOR_WITH_FRACT_BYTE) >> 8u)

#endif  /* (CY_PSOC5A) */

/* Following definitions are for the COMPATIBILITY ONLY, they are OBSOLETE. */
#define EC_EEPROM_State          EC_EEPROM_curState
#define EC_EEPROM_Status         EC_EEPROM_curStatus
#define EC_EEPROM_DataPtr        EC_EEPROM_dataPtrS1

#define EC_EEPROM_RwOffset1      EC_EEPROM_rwOffsetS1
#define EC_EEPROM_RwIndex1       EC_EEPROM_rwIndexS1
#define EC_EEPROM_WrProtect1     EC_EEPROM_wrProtectS1
#define EC_EEPROM_BufSize1       EC_EEPROM_bufSizeS1

#if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

    #define EC_EEPROM_DataPtr2   EC_EEPROM_dataPtrS2
    #define EC_EEPROM_Address1   EC_EEPROM_addrS1
    #define EC_EEPROM_Address2   EC_EEPROM_addrS2

    #define EC_EEPROM_RwOffset2  EC_EEPROM_rwOffsetS2
    #define EC_EEPROM_RwIndex2   EC_EEPROM_rwIndexS2
    #define EC_EEPROM_WrProtect2 EC_EEPROM_wrProtectS2
    #define EC_EEPROM_BufSize2   EC_EEPROM_bufSizeS2

#endif /* EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES */

/* Returns 1 if corresponding bit is set, otherwise 0 */
#define EC_EEPROM_IS_BIT_SET(value, mask) (((mask) == ((value) & (mask))) ? 0x01u : 0x00u)

#define EC_EEPROM_ADDRESS_SHIFT      (1u)
#define EC_EEPROM_ADDRESS_LSB_SHIFT  (8u)

/* 8-bit sub-address width */
#define EC_EEPROM_SUBADDR_8BIT       (0x00u)

/* 16-bit sub-address width */
#define EC_EEPROM_SUBADDR_16BIT      (0x01u)


/***************************************
*              Registers
***************************************/

/* I2C Extended Configuration Register */
#define EC_EEPROM_XCFG_REG       (* (reg8 *) EC_EEPROM_I2C_Prim__XCFG )
#define EC_EEPROM_XCFG_PTR       (  (reg8 *) EC_EEPROM_I2C_Prim__XCFG )

/* I2C Slave Adddress Register */
#define EC_EEPROM_ADDR_REG       (* (reg8 *) EC_EEPROM_I2C_Prim__ADR )
#define EC_EEPROM_ADDR_PTR       (  (reg8 *) EC_EEPROM_I2C_Prim__ADR )

/* I2C Configuration Register */
#define EC_EEPROM_CFG_REG        (* (reg8 *) EC_EEPROM_I2C_Prim__CFG )
#define EC_EEPROM_CFG_PTR        (  (reg8 *) EC_EEPROM_I2C_Prim__CFG )

/* I2C Control and Status Register */
#define EC_EEPROM_CSR_REG        (* (reg8 *) EC_EEPROM_I2C_Prim__CSR )
#define EC_EEPROM_CSR_PTR        (  (reg8 *) EC_EEPROM_I2C_Prim__CSR )

/* I2C Data Register */
#define EC_EEPROM_DATA_REG       (* (reg8 *) EC_EEPROM_I2C_Prim__D )
#define EC_EEPROM_DATA_PTR       (  (reg8 *) EC_EEPROM_I2C_Prim__D )

#if(CY_PSOC5A)

    /* I2C Clock Divide Factor Register */
    #define EC_EEPROM_CLKDIV_REG         (* (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV )
    #define EC_EEPROM_CLKDIV_PTR         (  (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV )

#else

     /*  8 LSB bits of the 10-bit Clock Divider */
    #define EC_EEPROM_CLKDIV1_REG        (* (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV1 )
    #define EC_EEPROM_CLKDIV1_PTR        (  (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV1 )

    /* 2 MSB bits of the 10-bit Clock Divider */
    #define EC_EEPROM_CLKDIV2_REG        (* (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV2 )
    #define EC_EEPROM_CLKDIV2_PTR        (  (reg8 *) EC_EEPROM_I2C_Prim__CLK_DIV2 )

#endif  /* (CY_PSOC5A) */

/* Power System Control Register 1 */
#define EC_EEPROM_PWRSYS_CR1_REG     (* (reg8 *) CYREG_PWRSYS_CR1 )
#define EC_EEPROM_PWRSYS_CR1_PTR     (  (reg8 *) CYREG_PWRSYS_CR1 )

/* I2C operation in Active Mode */
#define EC_EEPROM_PM_ACT_CFG_REG     (* (reg8 *) EC_EEPROM_I2C_Prim__PM_ACT_CFG )
#define EC_EEPROM_PM_ACT_CFG_PTR     (  (reg8 *) EC_EEPROM_I2C_Prim__PM_ACT_CFG )

/* I2C operation in Alternate Active (Standby) Mode */
#define EC_EEPROM_PM_STBY_CFG_REG    (* (reg8 *) EC_EEPROM_I2C_Prim__PM_STBY_CFG )
#define EC_EEPROM_PM_STBY_CFG_PTR    (  (reg8 *) EC_EEPROM_I2C_Prim__PM_STBY_CFG )


/***************************************
*       Register Constants
***************************************/

/* XCFG I2C Extended Configuration Register */
#define EC_EEPROM_XCFG_CLK_EN            (0x80u)
#define EC_EEPROM_XCFG_HDWR_ADDR_EN      (0x01u)

#if(CY_PSOC3 || CY_PSOC5LP)

    /* Force nack */
    #define EC_EEPROM_XCFG_FORCE_NACK            (0x10u)
    
    /* Ready to sleep */
    #define EC_EEPROM_XCFG_SLEEP_READY           (0x20u)
    
    /* if I2C block will be used as wake up source */
    #if(EC_EEPROM_ENABLE_WAKEUP == 1u)

        /* Should be set before entering sleep mode */
        #define EC_EEPROM_XCFG_I2C_ON            (0x40u)

        /* Enables the I2C regulator backup */
        #define EC_EEPROM_PWRSYS_CR1_I2C_BACKUP  (0x04u)

    #endif  /* (EC_EEPROM_ENABLE_WAKEUP == 1u) */

#endif  /* (CY_PSOC3 || CY_PSOC5LP) */

/* Data I2C Slave Data Register */
#define EC_EEPROM_SADDR_MASK        (0x7Fu)
#define EC_EEPROM_DATA_MASK         (0xFFu)
#define EC_EEPROM_READ_FLAG         (0x01u)

/* CFG I2C Configuration Register */

/* Pin Select for SCL/SDA lines */
#define EC_EEPROM_CFG_SIO_SELECT    (0x80u)

/* Pin Select */
#define EC_EEPROM_CFG_PSELECT       (0x40u)

/* Bus Error Interrupt Enable */
#define EC_EEPROM_CFG_BUS_ERR_IE    (0x20u)

/* Enable Interrupt on STOP condition */
#define EC_EEPROM_CFG_STOP_IE       (0x10u)

/* Enable Interrupt on STOP condition */
#define EC_EEPROM_CFG_STOP_ERR_IE   (0x10u)


#if(CY_PSOC5A)

    /* Clock rate select */
    #define EC_EEPROM_CFG_CLK_RATE_MSK  (0x0Cu)

    /* Clock rate select 100K */
    #define EC_EEPROM_CFG_CLK_RATE_100  (0x00u)

    /* Clock rate select 400K */
    #define EC_EEPROM_CFG_CLK_RATE_400  (0x04u)

    /* Clock rate select 50K */
    #define EC_EEPROM_CFG_CLK_RATE_050  (0x08u)

    /* Clock rate select Invalid */
    #define EC_EEPROM_CFG_CLK_RATE_RSVD (0x0Cu)

#else

    /* Clock rate mask. 1 for 50K, 0 for 100K and 400K */
    #define EC_EEPROM_CFG_CLK_RATE      (0x04u)

#endif  /* (CY_PSOC5A) */

/* Enable Slave operation */
#define EC_EEPROM_CFG_EN_SLAVE      (0x01u)

/* CSR I2C Control and Status Register */

/* Active high when bus error has occured */
#define EC_EEPROM_CSR_BUS_ERROR     (0x80u)

/* Set to 1 if lost arbitration in host mode */
#define EC_EEPROM_CSR_LOST_ARB      (0x40u)

/* Set to 1 if Stop has been detected */
#define EC_EEPROM_CSR_STOP_STATUS   (0x20u)

/* ACK response */
#define EC_EEPROM_CSR_ACK           (0x10u)

/* NAK response */
#define EC_EEPROM_CSR_NAK           (0x00u)

/* Set in firmware 0 = status bit, 1 Address is slave */
#define EC_EEPROM_CSR_ADDRESS       (0x08u)

/* Set in firmware 1 = transmit, 0 = receive. */
#define EC_EEPROM_CSR_TRANSMIT      (0x04u)

/* Last received bit. */
#define EC_EEPROM_CSR_LRB           (0x02u)

 /* Last received bit was an ACK */
#define EC_EEPROM_CSR_LRB_ACK       (0x00u)

/* Last received bit was an NAK */
#define EC_EEPROM_CSR_LRB_NAK       (0x02u)

/* Informs that last byte has been sent. */
#define EC_EEPROM_CSR_BYTE_COMPLETE (0x01u)

/* CLK_DIV I2C Clock Divide Factor Register */

/* Status bit, Set at Start and cleared at Stop condition */
#define EC_EEPROM_CLK_DIV_MSK       (0x07u)

/* Divide input clock by  1 */
#define EC_EEPROM_CLK_DIV_1         (0x00u)

/* Divide input clock by  2 */
#define EC_EEPROM_CLK_DIV_2         (0x01u)

/* Divide input clock by  4 */
#define EC_EEPROM_CLK_DIV_4         (0x02u)

/* Divide input clock by  8 */
#define EC_EEPROM_CLK_DIV_8         (0x03u)

/* Divide input clock by 16 */
#define EC_EEPROM_CLK_DIV_16        (0x04u)

/* Divide input clock by 32 */
#define EC_EEPROM_CLK_DIV_32        (0x05u)

/* Divide input clock by 64 */
#define EC_EEPROM_CLK_DIV_64        (0x06u)

/* Active Power Mode CFG Register - power enable mask */
#define EC_EEPROM_ACT_PWR_EN    EC_EEPROM_I2C_Prim__PM_ACT_MSK

/* Alternate Active (Standby) Power Mode CFG Register - power enable mask */
#define EC_EEPROM_STBY_PWR_EN    EC_EEPROM_I2C_Prim__PM_STBY_MSK

/* Number of the EC_EEPROM_isr interrupt. */
#define EC_EEPROM_ISR_NUMBER    EC_EEPROM_isr__INTC_NUMBER

/* Priority of the EC_EEPROM_isr interrupt. */
#define EC_EEPROM_ISR_PRIORITY  EC_EEPROM_isr__INTC_PRIOR_NUM

/* I2C state machine constants */

/* Wait for Start */
#define  EC_EEPROM_SM_IDLE              (0x00u)

/* Default address states */

/* Wait for sub-address */
#define  EC_EEPROM_SM_DEV1_WR_ADDR      (0x01u)

/* Wait for sub-address MSB */
#define  EC_EEPROM_SM_DEV1_WR_ADDR_MSB  (0x01u)

/* Wait for sub-address LSB */
#define  EC_EEPROM_SM_DEV1_WR_ADDR_LSB  (0x02u)

/* Get data from Master */
#define  EC_EEPROM_SM_DEV1_WR_DATA      (0x04u)

/* Send data to Master */
#define  EC_EEPROM_SM_DEV1_RD_DATA      (0x08u)

/* Second address states */

/* Wait for sub-address */
#define  EC_EEPROM_SM_DEV2_WR_ADDR      (0x11u)

/* Wait for sub-address MSB */
#define  EC_EEPROM_SM_DEV2_WR_ADDR_MSB  (0x11u)

/* Wait for sub-address LSB */
#define  EC_EEPROM_SM_DEV2_WR_ADDR_LSB  (0x12u)

/* Get data from Master */
#define  EC_EEPROM_SM_DEV2_WR_DATA      (0x14u)

/* Send data to Master */
#define  EC_EEPROM_SM_DEV2_RD_DATA      (0x18u)

#endif /* CY_EZI2C_EC_EEPROM_H */


/* [] END OF FILE */
