/*******************************************************************************
* File Name: EC_EEPROMINT.c
* Version 1.80
*
* Description:
*  This file contains the code that operates during the interrupt service
*  routine.  For this component, most of the runtime code is located in
*  the ISR.
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "EC_EEPROM.h"

uint8 EC_EEPROMnext_value = 0;

uint8   EC_EEPROM_EEPROM_row_queue[EC_EEPROM_EEPROM_ROW_QUEUE_LENGTH];
uint8   EC_EEPROM_EEPROM_row_queue_head   = 0;
uint8   EC_EEPROM_EEPROM_row_queue_tail   = 0;
uint8   EC_EEPROM_EEPROM_Contents[CYDEV_EE_SIZE];

/***************************************
*         System Variable
***************************************/

/* Current state of I2C state machine */
volatile uint8   EC_EEPROM_curState;

/* Status byte */
volatile uint8   EC_EEPROM_curStatus;

/* Pointer to data exposed to I2C Master */
volatile uint8 * EC_EEPROM_dataPtrS1;

#if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)

    /* Offset for read and write operations, set at each write sequence */
    volatile uint8   EC_EEPROM_rwOffsetS1;

    /* Points to next value to be read or written */
    volatile uint8   EC_EEPROM_rwIndexS1;

    /* Offset where data is read only */
    volatile uint8   EC_EEPROM_wrProtectS1;

    /* Size of array between 1 and 255 */
    volatile uint8   EC_EEPROM_bufSizeS1;

#else   /* 16 bit sub-address */

    /* Offset for read and write operations, set at each write sequence */
    volatile uint16  EC_EEPROM_rwOffsetS1;

    /* Points to next value to be read or written */
    volatile uint16  EC_EEPROM_rwIndexS1;

    /* Offset where data is read only */
    volatile uint16  EC_EEPROM_wrProtectS1;

    /* Size of array between 1 and 65535 */
    volatile uint16  EC_EEPROM_bufSizeS1;

#endif  /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */

/* If two slave addresses, creat second set of varaibles  */
#if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

    /* Pointer to data exposed to I2C Master */
    volatile uint8 * EC_EEPROM_dataPtrS2;

    /* Software address compare 1 */
    volatile uint8   EC_EEPROM_addrS1;

    /* Software address compare 2 */
    volatile uint8   EC_EEPROM_addrS2;

    /* Select 8 or 16 bit secondary addresses */
    #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)

        /* Offset for read and write operations, set at each write sequence */
        volatile uint8   EC_EEPROM_rwOffsetS2;

        /* Points to next value to be read or written */
        volatile uint8   EC_EEPROM_rwIndexS2;

        /* Offset where data is read only */
        volatile uint8   EC_EEPROM_wrProtectS2;

        /* Size of array between 1 and 255 */
        volatile uint8   EC_EEPROM_bufSizeS2;

    #else   /* 16 bit sub-address */

        /* Offset for read and write operations, set at each write sequence */
        volatile uint16  EC_EEPROM_rwOffsetS2;

        /* Points to next value to be read or written */
        volatile uint16  EC_EEPROM_rwIndexS2;

        /* Offset where data is read only */
        volatile uint16  EC_EEPROM_wrProtectS2;

        /* Size of array between 1 and 65535 */
        volatile uint16  EC_EEPROM_bufSizeS2;

    #endif  /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */

#endif  /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */


/*******************************************************************************
* Function Name: EC_EEPROM_ISR
********************************************************************************
*
* Summary:
*  Handle Interrupt Service Routine.
*
* Parameters:
*  EC_EEPROM_dataPtrS1: global variable, which stores pointer to the
*  data exposed to an I2C master for the first slave address.
*
*  EC_EEPROM_rwOffsetS1: global variable, which stores offset for read
*  and write operations, is set at each write sequence of the first slave
*  address.
*
*  EC_EEPROM_rwIndexS1: global variable, which stores pointer to the next
*  value to be read or written for the first slave address.
*
* EC_EEPROM_wrProtectS1: global variable, which stores offset where data
*  is read only for the first slave address.
*
* EC_EEPROM_bufSizeS1: global variable, which stores size of data array
*  exposed to an I2C master for the first slave address.
*
*  EC_EEPROM_dataPtrS2: global variable, which stores pointer to the
*  data exposed to an I2C master for the second slave address.
*
*  EC_EEPROM_rwOffsetS2: global variable, which stores offset for read
*  and write operations, is set at each write sequence of the second slave
*  device.
*
*  EC_EEPROM_rwIndexS2: global variable, which stores pointer to the next
*  value to be read or written for the second slave address.
*
* EC_EEPROM_wrProtectS2: global variable, which stores offset where data
*  is read only for the second slave address.
*
* EC_EEPROM_bufSizeS2: global variable, which stores size of data array
*  exposed to an I2C master for the second slave address.
*
* EC_EEPROM_curState: global variable, which stores current state of an
*  I2C state machine.
*
*  EC_EEPROM_curStatus: global variable, which stores current status of
*  the component.
*
* Return:
*  EC_EEPROM_rwOffsetS1: global variable, which stores offset for read
*  and write operations, is set at each write sequence of the first slave
*  address. Is reset if received slave address matches first slave address
*  and next operation will be read.
*
*  EC_EEPROM_rwIndexS1: global variable, which stores pointer to the next
*  value to be read or written for the first slave address. Is set to
*  EC_EEPROM_rwOffsetS1 and than incremented if received slave address
*  matches first slave address and next operation will be read.
*
*  EC_EEPROM_rwOffsetS2: global variable, which stores offset for read
*  and write operations, is set at each write sequence of the second slave
*  address. This variable is changes if new sub-address is passed to slave.
*
*  EC_EEPROM_rwIndexS2: global variable, which stores pointer to the next
*  value to be read or written for the second slave address. This variable is 
*  changes if new sub-address is passed to slave.
*
*******************************************************************************/
CY_ISR(EC_EEPROM_ISR)
{
    /* Making these static so not wasting time allocating
    *  on the stack each time and no one else can see them 
    */
    static uint8  tmp8;
    static uint8  tmpCsr;

    #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_16BIT)
        static uint16 tmp16;
    #endif /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_16BIT) */

    /* Entry from interrupt
    *  In hardware address compare mode, we can assume we only get interrupted
    *  when a valid address is recognized. In software address compare mode,
    *  we have to check every address after a start condition.
    */

    /* Make a copy so that we can check for stop condition after we are done */
    tmpCsr = EC_EEPROM_CSR_REG;
    
                                                                                                            // Check to see if a Start/Address is detected
                                                                                                            // - reset the state machine.
                                                                                                            // Check for a Read/Write condition.

    if(EC_EEPROM_IS_BIT_SET(tmpCsr, EC_EEPROM_CSR_ADDRESS))                                   // Is this an address?
    {                                                                                                       // ===================
    
            if(EC_EEPROM_IS_BIT_SET(EC_EEPROM_DATA_REG, EC_EEPROM_READ_FLAG))          // Read operation
            {                                                                                               // --------------
                                                                                                            // Prepare next read op, get data and place in register
                EC_EEPROM_DATA_REG   =  EC_EEPROM_dataPtrS1[EC_EEPROM_rwOffsetS1];     // Load first data byte
                EC_EEPROM_CSR_REG    = (EC_EEPROM_CSR_ACK | EC_EEPROM_CSR_TRANSMIT);   // ACK and transmit
                EC_EEPROM_rwIndexS1  =  EC_EEPROM_rwOffsetS1+1;                               // Set index to next address
                EC_EEPROMnext_value  =  EC_EEPROM_dataPtrS1[EC_EEPROM_rwIndexS1];      // Prefetch the next value so that it's ready in time.
                EC_EEPROM_curStatus |=  EC_EEPROM_STATUS_RD1BUSY;                             // Set read busy status
                EC_EEPROM_curState   =  EC_EEPROM_SM_DEV1_RD_DATA;                            // Prepare for read transaction
            }
            else                                                                                            // Write operation
            {                                                                                               // ---------------
                EC_EEPROM_CSR_REG    = EC_EEPROM_CSR_ACK;                                     // ACK and ready to receive addr
                EC_EEPROM_curStatus |= EC_EEPROM_STATUS_WR1BUSY;                              // Set Write activity
                EC_EEPROM_curState   = EC_EEPROM_SM_DEV1_WR_ADDR;                             // Prepare for read transaction
                EC_EEPROM_CFG_REG   |= EC_EEPROM_CFG_STOP_IE;                                 // Enable interrupt on stop
            }
    }
    else if(EC_EEPROM_IS_BIT_SET(tmpCsr, EC_EEPROM_CSR_BYTE_COMPLETE))                        // Data transfer
    {                                                                                                       // =============
        switch(EC_EEPROM_curState)                                                                   // Data transfer state machine
        {
            /* Address written from Master to Slave. */
            case EC_EEPROM_SM_DEV1_WR_ADDR:

                /* Save MSB of address */
                tmp16 = EC_EEPROM_DATA_REG;

                /* ACK and ready to receive addr */
                EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                /* Prepare to get LSB of Addr */
                EC_EEPROM_curState = EC_EEPROM_SM_DEV1_WR_ADDR_LSB;


                break;  /* case EC_EEPROM_SM_DEV1_WR_ADDR */

            /* Only used with 16-bit interface */
            case EC_EEPROM_SM_DEV1_WR_ADDR_LSB:

                /* Create offset */
                tmp16 = (tmp16 << EC_EEPROM_ADDRESS_LSB_SHIFT) | EC_EEPROM_DATA_REG;

                /* Check range */
                if(tmp16 < EC_EEPROM_bufSizeS1)
                {
                    /* ACK and ready to receive addr */
                    EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                    /* Set offset to new value */
                    EC_EEPROM_rwOffsetS1 = tmp16;

                    /* Reset index to offset value */
                    EC_EEPROM_rwIndexS1 = tmp16;

                    /* Prepare for write transaction */
                    EC_EEPROM_curState = EC_EEPROM_SM_DEV1_WR_DATA;
                }
                else    /* Out of range, NAK data and don't set offset */
                {
                    /* NAK the master */
                    EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                }
                break; /* case EC_EEPROM_SM_DEV1_WR_ADDR_LSB */



            /* Data written from Master to Slave. */
            case EC_EEPROM_SM_DEV1_WR_DATA:
                
                /* Check for valid range */
                if(EC_EEPROM_rwIndexS1 < EC_EEPROM_wrProtectS1)
                {
                    /* Get data, to ACK quickly */
                    tmp8 = EC_EEPROM_DATA_REG;

                    /* ACK and ready to receive sub addr */
                    EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                    /* Write data to array */
                    EC_EEPROM_dataPtrS1[EC_EEPROM_rwIndexS1] = tmp8;

                    /* Increment pointer */
                    EC_EEPROM_rwIndexS1++;
                    
                    if (!(EC_EEPROM_rwIndexS1 & 0x000F))                             // Just finished writing a block?
                    {
                        EC_EEPROM_EEPROM_row_queue[EC_EEPROM_EEPROM_row_queue_head] = ((EC_EEPROM_rwIndexS1)>>4) -1;
                        EC_EEPROM_EEPROM_row_queue_head++;
                        EC_EEPROM_EEPROM_row_queue_head &= EC_EEPROM_EEPROM_ROW_QUEUE_LENGTH-1;                        
                    }
                    
                }
                else
                {
                    /* NAK cause beyond write area */
                    EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                }
            break;  /* EC_EEPROM_SM_DEV1_WR_DATA */


            /* Data read by Master from Slave */
            case EC_EEPROM_SM_DEV1_RD_DATA:

                /* Check ACK/NAK */
                if((tmpCsr & EC_EEPROM_CSR_LRB) == EC_EEPROM_CSR_LRB_ACK)
                {
                    /* Check for valid range */
                    if(EC_EEPROM_rwIndexS1 < EC_EEPROM_bufSizeS1)
                    {
                        /* Get data from array */
                        EC_EEPROM_DATA_REG = EC_EEPROMnext_value;

                        /* Send Data */
                        EC_EEPROM_CSR_REG = EC_EEPROM_CSR_TRANSMIT;

                        /* Increment pointer */
                        EC_EEPROM_rwIndexS1++;
                        
                        EC_EEPROMnext_value = EC_EEPROM_dataPtrS1[EC_EEPROM_rwIndexS1];
                        
                    }
                    else    /* No valid range */
                    {
                        /* Out of range send FFs */
                        EC_EEPROM_DATA_REG = EC_EEPROM_DUMMY_DATA;

                        /* Send Data */
                        EC_EEPROM_CSR_REG = EC_EEPROM_CSR_TRANSMIT;
                    }
                }
                else    /* Data was NAKed */
                {
                    /* Send dummy data at the end of read transaction */
                    EC_EEPROM_DATA_REG = EC_EEPROM_DUMMY_DATA;

                    /* Clear transmit bit at the end of read transaction */
                    EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                    
                    /* Clear Busy Flag */
                    EC_EEPROM_curStatus &= ~EC_EEPROM_STATUS_BUSY;

                    /* Error or Stop, reset state */
                    EC_EEPROM_curState = EC_EEPROM_SM_IDLE;

                }
            break;  /* EC_EEPROM_SM_DEV1_RD_DATA */

            /* Second Device Address */
            #if(EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES)

                case EC_EEPROM_SM_DEV2_WR_ADDR:

                    /* If 8-bit interface, Advance to WR_Data, else to ADDR2 */
                    #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT)
                        
                        tmp8 = EC_EEPROM_DATA_REG;
                        if(tmp8 < EC_EEPROM_bufSizeS2)
                        {
                            /* ACK and ready to receive addr */
                            EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                            /* Set offset to new value */
                            EC_EEPROM_rwOffsetS2 = tmp8;

                            /* Reset index to offset value */
                            EC_EEPROM_rwIndexS2 = tmp8;

                            /* Prepare for write transaction */
                            EC_EEPROM_curState = EC_EEPROM_SM_DEV2_WR_DATA;
                        }
                        else    /* Out of range, NAK data and don't set offset */
                        {
                            /* NAK the master */
                            EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                        }
                    #else
                        /* Save LSB of address */
                        tmp16 = EC_EEPROM_DATA_REG;

                        /* ACK and ready to receive addr */
                        EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                        /* Prepare to get LSB of Addr */
                        EC_EEPROM_curState = EC_EEPROM_SM_DEV2_WR_ADDR_LSB;
                    #endif  /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_8BIT) */

                break;  /* EC_EEPROM_SM_DEV2_WR_ADDR */

                #if(EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_16BIT)

                    /* Only used with 16-bit interface */
                    case EC_EEPROM_SM_DEV2_WR_ADDR_LSB:
                        /* Create offset */
                        tmp16 = (tmp16 << 8u) | EC_EEPROM_DATA_REG;
                        if(tmp16 < EC_EEPROM_bufSizeS2)
                        {
                            /* ACK and ready to receive addr */
                            EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                            /* Set offset to new value */
                            EC_EEPROM_rwOffsetS2 = tmp16;

                            /* Reset index to offset value */
                            EC_EEPROM_rwIndexS2 = tmp16;

                            /* Prepare for write transaction */
                            EC_EEPROM_curState = EC_EEPROM_SM_DEV2_WR_DATA;
                        }
                        else    /* Out of range, NAK data and don't set offset */
                        {
                            /* NAK the master */
                            EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                        }
                        break; /* EC_EEPROM_SM_DEV2_WR_ADDR_LSB */

                #endif   /* (EC_EEPROM_SUBADDR_WIDTH == EC_EEPROM_SUBADDR_16BIT) */


                /* Data written from Master to Slave. */
                case EC_EEPROM_SM_DEV2_WR_DATA:
                    
                    /* Check for valid range */
                    if(EC_EEPROM_rwIndexS2 < EC_EEPROM_wrProtectS2)
                    {
                        /* Get data, to ACK quickly */
                        tmp8 = EC_EEPROM_DATA_REG;

                        /* ACK and ready to receive sub addr */
                        EC_EEPROM_CSR_REG = EC_EEPROM_CSR_ACK;

                        /* Write data to array */
                        EC_EEPROM_dataPtrS2[EC_EEPROM_rwIndexS2] = tmp8;

                        /* Inc pointer */
                        EC_EEPROM_rwIndexS2++;
                    }
                    else
                    {
                        /* NAK cause beyond write area */
                        EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                    }
                    break;  /* EC_EEPROM_SM_DEV2_WR_DATA */

                    /* Data read by Master from Slave */
                    case EC_EEPROM_SM_DEV2_RD_DATA:
                    
                        if((tmpCsr & EC_EEPROM_CSR_LRB) == EC_EEPROM_CSR_LRB_ACK)
                        {   /* ACKed */
                            /* Check for valid range */
                            if(EC_EEPROM_rwIndexS2 < EC_EEPROM_bufSizeS2)
                            {   /* Check ACK/NAK */
                                /* Get data from array */
                                EC_EEPROM_DATA_REG = EC_EEPROM_dataPtrS2[EC_EEPROM_rwIndexS2];

                                /* Send Data */
                                EC_EEPROM_CSR_REG = EC_EEPROM_CSR_TRANSMIT;

                                /* Increment pointer */
                                EC_EEPROM_rwIndexS2++;    
                            }
                            else    /* Not valid range */
                            {
                                /* Out of range send FFs */
                                EC_EEPROM_DATA_REG = EC_EEPROM_DUMMY_DATA;

                                /* Send Data */
                                EC_EEPROM_CSR_REG = EC_EEPROM_CSR_TRANSMIT;
                            }
                        }
                        else    /* NAKed */
                        {
                            /* Out of range send FFs */
                            EC_EEPROM_DATA_REG = EC_EEPROM_DUMMY_DATA;

                            /* Send Data */
                            EC_EEPROM_CSR_REG = EC_EEPROM_CSR_TRANSMIT;

                            /* Clear busy status */
                            EC_EEPROM_curStatus &= ~EC_EEPROM_STATUS_BUSY;

                            /* Error or Stop, reset state */
                            EC_EEPROM_curState = EC_EEPROM_SM_IDLE;
                        }   /* End if ACK/NAK */
                            
                        break;  /* EC_EEPROM_SM_DEV2_RD_DATA */

            #endif  /* (EC_EEPROM_ADDRESSES == EC_EEPROM_TWO_ADDRESSES) */

            default:
                /* Invalid state, Reset */
                EC_EEPROM_curState = EC_EEPROM_SM_IDLE;

                /* Reset offsets and index */
                EC_EEPROM_rwOffsetS1 = 0u;

                /* Clear index */
                EC_EEPROM_rwIndexS1 = 0u;

                /* Dummy NAK to release bus */
                EC_EEPROM_CSR_REG = EC_EEPROM_CSR_NAK;
                break;

        }  /* End switch/case EC_EEPROM_curState */

    }   /* (tmpCsr & EC_EEPROM_CSR_ADDRESS) */

    /* Check if Stop was detected */
    if(EC_EEPROM_IS_BIT_SET(EC_EEPROM_CSR_REG, EC_EEPROM_CSR_STOP_STATUS))
    {
        /* Clear Busy Flag */
        EC_EEPROM_curStatus &= ~EC_EEPROM_STATUS_BUSY;

        /* error or stop - reset state */
        EC_EEPROM_curState = EC_EEPROM_SM_IDLE;

        /* Disable interrupt on Stop */
        EC_EEPROM_CFG_REG &= ~EC_EEPROM_CFG_STOP_IE;
    }
}


/* [] END OF FILE */
