/*******************************************************************************
* File Name: EC_SOMI.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "EC_SOMI.h"


/*******************************************************************************
* Function Name: EC_SOMI_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void EC_SOMI_Write(uint8 value) 
{
    uint8 staticBits = (EC_SOMI_DR & (uint8)(~EC_SOMI_MASK));
    EC_SOMI_DR = staticBits | ((uint8)(value << EC_SOMI_SHIFT) & EC_SOMI_MASK);
}


/*******************************************************************************
* Function Name: EC_SOMI_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void EC_SOMI_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(EC_SOMI_0, mode);
}


/*******************************************************************************
* Function Name: EC_SOMI_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro EC_SOMI_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 EC_SOMI_Read(void) 
{
    return (EC_SOMI_PS & EC_SOMI_MASK) >> EC_SOMI_SHIFT;
}


/*******************************************************************************
* Function Name: EC_SOMI_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 EC_SOMI_ReadDataReg(void) 
{
    return (EC_SOMI_DR & EC_SOMI_MASK) >> EC_SOMI_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(EC_SOMI_INTSTAT) 

    /*******************************************************************************
    * Function Name: EC_SOMI_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 EC_SOMI_ClearInterrupt(void) 
    {
        return (EC_SOMI_INTSTAT & EC_SOMI_MASK) >> EC_SOMI_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
