/*******************************************************************************
* File Name: EC_SPI_Clk.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_EC_SPI_Clk_H)
#define CY_CLOCK_EC_SPI_Clk_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void EC_SPI_Clk_Start(void) ;
void EC_SPI_Clk_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void EC_SPI_Clk_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void EC_SPI_Clk_StandbyPower(uint8 state) ;
void EC_SPI_Clk_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 EC_SPI_Clk_GetDividerRegister(void) ;
void EC_SPI_Clk_SetModeRegister(uint8 modeBitMask) ;
void EC_SPI_Clk_ClearModeRegister(uint8 modeBitMask) ;
uint8 EC_SPI_Clk_GetModeRegister(void) ;
void EC_SPI_Clk_SetSourceRegister(uint8 clkSource) ;
uint8 EC_SPI_Clk_GetSourceRegister(void) ;
#if defined(EC_SPI_Clk__CFG3)
void EC_SPI_Clk_SetPhaseRegister(uint8 clkPhase) ;
uint8 EC_SPI_Clk_GetPhaseRegister(void) ;
#endif /* defined(EC_SPI_Clk__CFG3) */

#define EC_SPI_Clk_Enable()                       EC_SPI_Clk_Start()
#define EC_SPI_Clk_Disable()                      EC_SPI_Clk_Stop()
#define EC_SPI_Clk_SetDivider(clkDivider)         EC_SPI_Clk_SetDividerRegister(clkDivider, 1)
#define EC_SPI_Clk_SetDividerValue(clkDivider)    EC_SPI_Clk_SetDividerRegister((clkDivider) - 1, 1)
#define EC_SPI_Clk_SetMode(clkMode)               EC_SPI_Clk_SetModeRegister(clkMode)
#define EC_SPI_Clk_SetSource(clkSource)           EC_SPI_Clk_SetSourceRegister(clkSource)
#if defined(EC_SPI_Clk__CFG3)
#define EC_SPI_Clk_SetPhase(clkPhase)             EC_SPI_Clk_SetPhaseRegister(clkPhase)
#define EC_SPI_Clk_SetPhaseValue(clkPhase)        EC_SPI_Clk_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(EC_SPI_Clk__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define EC_SPI_Clk_CLKEN              (* (reg8 *) EC_SPI_Clk__PM_ACT_CFG)
#define EC_SPI_Clk_CLKEN_PTR          ((reg8 *) EC_SPI_Clk__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define EC_SPI_Clk_CLKSTBY            (* (reg8 *) EC_SPI_Clk__PM_STBY_CFG)
#define EC_SPI_Clk_CLKSTBY_PTR        ((reg8 *) EC_SPI_Clk__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define EC_SPI_Clk_DIV_LSB            (* (reg8 *) EC_SPI_Clk__CFG0)
#define EC_SPI_Clk_DIV_LSB_PTR        ((reg8 *) EC_SPI_Clk__CFG0)
#define EC_SPI_Clk_DIV_PTR            ((reg16 *) EC_SPI_Clk__CFG0)

/* Clock MSB divider configuration register. */
#define EC_SPI_Clk_DIV_MSB            (* (reg8 *) EC_SPI_Clk__CFG1)
#define EC_SPI_Clk_DIV_MSB_PTR        ((reg8 *) EC_SPI_Clk__CFG1)

/* Mode and source configuration register */
#define EC_SPI_Clk_MOD_SRC            (* (reg8 *) EC_SPI_Clk__CFG2)
#define EC_SPI_Clk_MOD_SRC_PTR        ((reg8 *) EC_SPI_Clk__CFG2)

#if defined(EC_SPI_Clk__CFG3)
/* Analog clock phase configuration register */
#define EC_SPI_Clk_PHASE              (* (reg8 *) EC_SPI_Clk__CFG3)
#define EC_SPI_Clk_PHASE_PTR          ((reg8 *) EC_SPI_Clk__CFG3)
#endif /* defined(EC_SPI_Clk__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define EC_SPI_Clk_CLKEN_MASK         EC_SPI_Clk__PM_ACT_MSK
#define EC_SPI_Clk_CLKSTBY_MASK       EC_SPI_Clk__PM_STBY_MSK

/* CFG2 field masks */
#define EC_SPI_Clk_SRC_SEL_MSK        EC_SPI_Clk__CFG2_SRC_SEL_MASK
#define EC_SPI_Clk_MODE_MASK          (~(EC_SPI_Clk_SRC_SEL_MSK))

#if defined(EC_SPI_Clk__CFG3)
/* CFG3 phase mask */
#define EC_SPI_Clk_PHASE_MASK         EC_SPI_Clk__CFG3_PHASE_DLY_MASK
#endif /* defined(EC_SPI_Clk__CFG3) */

#endif /* CY_CLOCK_EC_SPI_Clk_H */


/* [] END OF FILE */
