/*******************************************************************************
* File Name: Mux_ADC.c
* Version 1.70
*
*  Description:
*    This file contains functions for the AMuxSeq.
*
*   Note:
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Mux_ADC.h"

uint8 Mux_ADC_initVar = 0u;


/*******************************************************************************
* Function Name: Mux_ADC_Start
********************************************************************************
* Summary:
*  Disconnect all channels. The next time Next is called, channel 0 will be
*  connected.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Mux_ADC_Start(void)
{
    Mux_ADC_DisconnectAll();
    Mux_ADC_initVar = 1u;
}


/*******************************************************************************
* Function Name: Mux_ADC_Init
********************************************************************************
* Summary:
*  Disconnect all channels. The next time Next is called, channel 0 will be
*  connected.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Mux_ADC_Init(void)
{
    Mux_ADC_DisconnectAll();
}


/*******************************************************************************
* Function Name: Mux_ADC_Stop
********************************************************************************
* Summary:
*  Disconnect all channels. The next time Next is called, channel 0 will be
*  connected.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Mux_ADC_Stop(void)
{
    Mux_ADC_DisconnectAll();
}

#if(Mux_ADC_MUXTYPE == Mux_ADC_MUX_DIFF)

extern int8 Mux_ADC_CYAMUXSIDE_A_curChannel;


/*******************************************************************************
* Function Name: Mux_ADC_Next
********************************************************************************
* Summary:
*  Disconnects the previous channel and connects the next one in the sequence.
*  When Next is called for the first time after Init, Start, Enable, Stop, or
*  DisconnectAll, it connects channel 0.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Mux_ADC_Next(void)
{
    Mux_ADC_CYAMUXSIDE_A_Next();
    Mux_ADC_CYAMUXSIDE_B_Next();
}


/*******************************************************************************
* Function Name: Mux_ADC_DisconnectAll
********************************************************************************
* Summary:
*  This function disconnects all channels. The next time Next is called, channel
*  0 will be connected.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Mux_ADC_DisconnectAll(void)
{
    Mux_ADC_CYAMUXSIDE_A_DisconnectAll();
    Mux_ADC_CYAMUXSIDE_B_DisconnectAll();
}


/*******************************************************************************
* Function Name: Mux_ADC_GetChannel
********************************************************************************
* Summary:
*  The currently connected channel is retuned. If no channel is connected
*  returns -1.
*
* Parameters:
*  void
*
* Return:
*  The current channel or -1.
*
*******************************************************************************/
int8 Mux_ADC_GetChannel(void)
{
    return Mux_ADC_CYAMUXSIDE_A_curChannel;
}

#else

extern int8 Mux_ADC_curChannel;


/*******************************************************************************
* Function Name: Mux_ADC_GetChannel
********************************************************************************
* Summary:
*  The currently connected channel is retuned. If no channel is connected
*  returns -1.
*
* Parameters:
*  void
*
* Return:
*  The current channel or -1.
*
*******************************************************************************/
int8 Mux_ADC_GetChannel(void)
{
    return Mux_ADC_curChannel;
}

#endif


/* [] END OF FILE */
