/*******************************************************************************
* File Name: RESET_ET1200.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RESET_ET1200.h"


/*******************************************************************************
* Function Name: RESET_ET1200_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void RESET_ET1200_Write(uint8 value) 
{
    uint8 staticBits = (RESET_ET1200_DR & (uint8)(~RESET_ET1200_MASK));
    RESET_ET1200_DR = staticBits | ((uint8)(value << RESET_ET1200_SHIFT) & RESET_ET1200_MASK);
}


/*******************************************************************************
* Function Name: RESET_ET1200_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void RESET_ET1200_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(RESET_ET1200_0, mode);
}


/*******************************************************************************
* Function Name: RESET_ET1200_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro RESET_ET1200_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 RESET_ET1200_Read(void) 
{
    return (RESET_ET1200_PS & RESET_ET1200_MASK) >> RESET_ET1200_SHIFT;
}


/*******************************************************************************
* Function Name: RESET_ET1200_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 RESET_ET1200_ReadDataReg(void) 
{
    return (RESET_ET1200_DR & RESET_ET1200_MASK) >> RESET_ET1200_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(RESET_ET1200_INTSTAT) 

    /*******************************************************************************
    * Function Name: RESET_ET1200_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 RESET_ET1200_ClearInterrupt(void) 
    {
        return (RESET_ET1200_INTSTAT & RESET_ET1200_MASK) >> RESET_ET1200_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
