//
// © 2010 Shadow Robot Company Limited.
//
// FileName:        this_node.c
// Dependencies:    
// Processor:       PSoC3, PSoC5
// Compiler:        C51
//
//  +------------------------------------------------------------------------+
//  | This file is part of The Shadow Robot PSoC firmware code base.         |
//  |                                                                        |
//  | It is free software: you can redistribute it and/or modify             |
//  | it under the terms of the GNU General Public License as published by   |
//  | the Free Software Foundation, either version 3 of the License, or      |
//  | (at your option) any later version.                                    |
//  |                                                                        |
//  | It is distributed in the hope that it will be useful,                  |
//  | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
//  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
//  | GNU General Public License for more details.                           |
//  |                                                                        |
//  | You should have received a copy of the GNU General Public License      |
//  | along with this code repository. The text of the license can be found  |
//  | in gpl.txt. If not, see <http://www.gnu.org/licenses/>.                |
//  +------------------------------------------------------------------------+
//
//
//
//
//  Doxygen
//  -------
//
//! @file
//
//! @group

#include "this_node.h"


int16u  stacker_detect_table[14]    = {4150, 620,722,865,996,1155,1332,1518,1681,1869,2048,2246,2433,2625};
int8u   stackers_found[4]           = {0,0,0,0};
int16u  flags               = 0;
int8u   testingHardware     = 0;
int8u   currentAdcChannel   = 0;
int8u   adcInProgress       = 0;                

void __assert_dynamic_fail(const char *fmt,...)
{
}


void Setup_ADC_For_Stacker_Detect(void)
{
    Mux_ADC_Start();
    
    ADC_Stop();
    ADC_SelectConfiguration(2, 0);
    ADC_Start();
    
    Mux_ADC_Init();
}

void Setup_ADC_For_Stacker_Sampling(void)
{

    Mux_ADC_Start();
    
    ADC_Stop();
    ADC_SelectConfiguration(1, 0);
    ADC_Start();
    
    Mux_ADC_Init();   
}

void Detect_Stacker()
{

    int8u i, s;
    int16u ADC_result;
    
    Setup_ADC_For_Stacker_Detect();
    
    while(Mux_ADC_GetChannel() != NUM_ANALOGUE_INPUTS)                          // Switch the multiplexer to the DETECT_0 pin
        Mux_ADC_Next();

    for (s=0; s<4; s++)                                                         // We have 4 detect pins
    {
        ADC_StartConvert();                                                     // Take the sample
        ADC_IsEndConversion(ADC_WAIT_FOR_RESULT);                               
        ADC_result = ADC_GetResult16();
        
        for (i=0; i<=13; i++)
        {
            if (( ADC_result - (stacker_detect_table[i]-50) ) < 130 )
                break;
        }

        if (ADC_result < 3000)
            stackers_found[3-s] = i;
        else
            stackers_found[3-s] = 0;

        Mux_ADC_Next() ;
    }
    
    flags = 0;
    
    if (stackers_found[0])
    {
        flags |=  RONEX_02000009_FLAGS_STACKER_0_PRESENT;
        if (stackers_found[0] != STACKER_TYPE)  flags |= RONEX_02000009_FLAGS_STACKER_0_ERROR;
    }
    
    if (stackers_found[1])
    {
        flags |=  RONEX_02000009_FLAGS_STACKER_1_PRESENT;
        if (stackers_found[1] != STACKER_TYPE)  flags |= RONEX_02000009_FLAGS_STACKER_1_ERROR;
    }

    if (stackers_found[2])
    {
        flags |=  RONEX_02000009_FLAGS_STACKER_2_PRESENT;
        if (stackers_found[2] != STACKER_TYPE)  flags |= RONEX_02000009_FLAGS_STACKER_2_ERROR;
    }

    if (stackers_found[3])
    {
        flags |=  RONEX_02000009_FLAGS_STACKER_3_PRESENT;
        if (stackers_found[3] != STACKER_TYPE)  flags |= RONEX_02000009_FLAGS_STACKER_3_ERROR;
    }
    
    Setup_ADC_For_Stacker_Sampling();
}



void Initialise_This_Node(void)
{
    CyGlobalIntEnable;
    
    ADC_Start();
    Detect_Stacker();
    
    EC_CS_Write(1);
    EC_SPI_Clk_Start();
    EC_SPI_Start();
        
    EC_EEPROM_Start();
    
    EC_EEPROM_WriteRAMInt16u(0x0205, 0x00);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0000, 0x01);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0000, 0x02);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0000, 0x03);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0xC001, 0x04);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0000, 0x05);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0000, 0x06);             // SPI mode
    EC_EEPROM_WriteRAMInt16u(0x0011, 0x07);             // SPI mode
    
    EC_EEPROM_WriteRAMInt16u(PRODUCT_CODE_L, 0x0A);     // Product ID **************************************************************
    EC_EEPROM_WriteRAMInt16u(PRODUCT_CODE_H, 0x0B);
    
    et1200_initialise();      
    ADC_Interrupt_Start();
}

void Platform_Init_Callback(void)
{
    Setup_ADC_For_Stacker_Sampling();
}




void Begin_ADC_Sampling(void)
{
    currentAdcChannel   = 0;
    adcInProgress       = 1;
    
    Mux_ADC_Start();
    Mux_ADC_Next();
    ADC_StartConvert();
}


void Handle_ADC_Interrupt(void)
{
    status_struct.analogue_in[currentAdcChannel] = ADC_GetResult16();
    currentAdcChannel++;   
    
    if (currentAdcChannel < NUM_ANALOGUE_INPUTS)
    {
        Mux_ADC_Next();
        ADC_StartConvert();
    }
    else
    {
        adcInProgress = 0;
    }
}


void Handle_Command_Normal(void)
{
    int8u triggers=0;
    int8u spiModes = 0;
    
    Begin_ADC_Sampling();

    DC_Motor_1_Setup_PWM(command_struct.motor_packet_command[0].period);
    DC_Motor_2_Setup_PWM(command_struct.motor_packet_command[1].period);
    
    DC_Motor_1_Set_Motor_Power(command_struct.motor_packet_command[0].onTime);
    DC_Motor_2_Set_Motor_Power(command_struct.motor_packet_command[1].onTime);
    
    status_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_NORMAL;
}



#define offsetof(st, m) ((size_t)(&((st *)0)->m))

#define SWAP_BYTES_IN_COMMAND(member_name)  {int8u t;                                                                           \
                                             t=((int8u*)&command_struct)[offsetof(RONEX_COMMAND_02000009, member_name)];        \
                                               ((int8u*)&command_struct)[offsetof(RONEX_COMMAND_02000009, member_name)]         \
                                             = ((int8u*)&command_struct)[offsetof(RONEX_COMMAND_02000009, member_name)+1];      \
                                               ((int8u*)&command_struct)[offsetof(RONEX_COMMAND_02000009, member_name)+1] = t;}
#define SWAP_BYTES_IN_STRUCT(member_name)  {int8u t;                                                                            \
                                             t=((int8u*)&status_struct)[offsetof(RONEX_STATUS_02000009, member_name)];          \
                                               ((int8u*)&status_struct)[offsetof(RONEX_STATUS_02000009, member_name)]           \
                                             = ((int8u*)&status_struct)[offsetof(RONEX_STATUS_02000009, member_name)+1];        \
                                               ((int8u*)&status_struct)[offsetof(RONEX_STATUS_02000009, member_name)+1] = t;}

void Handle_Default(void)
{
    status_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_ERROR;
}

void Handle_Command(void)
{
    // ---------------------------------------------------------
    // Deal with incomming command data, write it to the outputs hello
    // ---------------------------------------------------------
    
    union16 *command_array = (int16u*)&command_struct;
    
    if (!testingHardware)
    {
        Read_Command_DMA();
    }
    
        
    SWAP_BYTES_IN_COMMAND(command_type);
        
    switch (command_struct.command_type)
    {
        case RONEX_COMMAND_02000009_COMMAND_TYPE_NORMAL:
            break;
            
        default:
            Handle_Default();
            break;
      }
}


union16 u16;
union32 u32;
union16 *status_array = (union16*)&status_struct;

void Handle_Status(void)
{
    // -------------------------------------------
    // Sample inputs, and write them to the ET1200
    // -------------------------------------------
    
    // ADC sampling is now handled in Handle_Command().
    // Samples are taken in parallel with SPI transactions.
    
    //status_struct.command_type = command_struct.command_type;

    int8u i;
    
    while (adcInProgress)
    {
    }
    
    SWAP_BYTES_IN_STRUCT(command_type);
    
    //if (status_struct.command_type == RONEX_COMMAND_02000009_COMMAND_TYPE_NORMAL)
    //{
        for (i=0; i<6; i++)
        {
            SWAP_BYTES_IN_STRUCT(analogue_in[i]);
        }   
        

        Write_Status_DMA();
    
}


void Safe_Operational_Mode(void)
{
    Read_Command_DMA();
    Handle_Status();
}

void Pre_Operational_Mode(void)
{
}


void Operational_Mode(void)
{
    Handle_Command();
    Handle_Status();
}

void Init_Mode(void)
{
}


void Sync_Manager_1_Callback(void)
{
}

int8u channel=0;
void TestHardware(void)
{
    testingHardware = 1;

    CyGlobalIntEnable;
    
    EtherCAT_LED_Set_Flash(EtherCAT_LED_FLASH_PATTERN_OFF);
    Initialise_This_Node();
    
    //ADS1158_Initialise();
    /*
    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REG;
    command_struct.command_data_0 = 0x03FF;
    command_struct.command_data_1 = 0x03FF;
    command_struct.command_data_2 = 0x03FF;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();
    
    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REG;
    command_struct.command_data_0 = 0x0400;
    command_struct.command_data_1 = 0x0400;
    command_struct.command_data_2 = 0x0400;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();

    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REG;
    command_struct.command_data_0 = 0x0500;
    command_struct.command_data_1 = 0x0500;
    command_struct.command_data_2 = 0x0500;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();
    */
/*
    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_GET_CONFIG_INFO;
    command_struct.command_data_0 = 0x03FF;
    command_struct.command_data_1 = 0x0300;
    command_struct.command_data_2 = 0x0300;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();
    Handle_Status();
    
    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REGS;
    command_struct.command_data_0 = 0x0400;
    command_struct.command_data_1 = 0x0400;
    command_struct.command_data_2 = 0x0400;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();

    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REGS;
    command_struct.command_data_0 = 0x05C2;
    command_struct.command_data_1 = 0x05FF;
    command_struct.command_data_2 = 0x05FF;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();    

    command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_WRITE_REG;
    command_struct.command_data_0 = 0x063D;
    command_struct.command_data_1 = 0x0600;
    command_struct.command_data_2 = 0x0600;
    SWAP_BYTES_IN_COMMAND(command_type);
    SWAP_BYTES_IN_COMMAND(command_data_0);
    SWAP_BYTES_IN_COMMAND(command_data_1);
    SWAP_BYTES_IN_COMMAND(command_data_2);
    Handle_Command();    
  */  
    
    while(1)
    {
        command_struct.command_type = RONEX_COMMAND_02000009_COMMAND_TYPE_NORMAL;
        SWAP_BYTES_IN_COMMAND(command_type);
        Handle_Command();

        
        //ADS1158_Read_All_Channels(samples0, samples1, samples2);
        CyDelay(1);
    }
}


/* [] END OF FILE */
